now let's no longer put project quality evaluation in project plan. now let's have a formal support for it.

in workplace, let's create a sub menu called Project Quality Evalution.

When click on project quality evalution, the right content view should should Project Quality Evaluation View.

At top of the evalution view, so action bar, 
- it includes action Evaluate Project Quality, when click on it, it should popup console bar, just like others to prompt to evaluate project quality.
- if project-quality-evaluation.md exists, it includes actions Refactoring Button, when hover show options such as, Refactor All, Refactor Requirement, Refactor Feature, Refactor Test, Refactor Tracing Decorators ..., for each of the should have it's copilot prompt, it should be able to configure in copilot prompt.json. when click on it, it should popup console bar, just like others to prompt to refactor.


below action bar show project-quality-evaluation.md, for  project-quality-evaluation.md, let's no longer put in plan folder, let's move to quality-evaluation folder